@@ -16,7 +16,7 @@ AnyEvent::Handle - non-blocking I/O on file handles via AnyEvent
 
 =cut
 
-our $VERSION = 4.32;
+our $VERSION = 4.33;
 
 =head1 SYNOPSIS
 
@@ -376,10 +376,14 @@ sub on_timeout {
 =item $handle->autocork ($boolean)
 
 Enables or disables the current autocork behaviour (see C<autocork>
-constructor argument).
+constructor argument). Changes will only take effect on the next write.
 
 =cut
 
+sub autocork {
+   $_[0]{autocork} = $_[1];
+}
+
 =item $handle->no_delay ($boolean)
 
 Enables or disables the C<no_delay> setting (see constructor argument of
