@@ -84,14 +84,14 @@ thousands of timers, though, or your timers have very small timeouts.
 package AnyEvent::Impl::Perl;
 
 no warnings;
-use strict;
+use strict qw(vars subs);
 
-use Scalar::Util ();
+use Scalar::Util qw(weaken);
 
 use AnyEvent ();
 use AnyEvent::Util ();
 
-our $VERSION = 4.32;
+our $VERSION = 4.33;
 
 our ($NOW, $MNOW);
 
@@ -223,8 +223,10 @@ sub one_event {
 sub io {
    my ($class, %arg) = @_;
 
+   my $fd = fileno $arg{fh};
+
    my $self = bless [
-      $arg{fh},
+      $fd,
       $arg{poll} eq "w",
       $arg{cb},
       # q-idx
@@ -233,14 +235,13 @@ sub io {
    my $fds = $fds[$self->[1]];
 
    # add watcher to fds structure
-   my $fd = fileno $self->[0];
    my $q = $fds->[W][$fd] ||= [];
 
    (vec $fds->[V], $fd, 1) = 1;
 
    $self->[3] = @$q;
    push @$q, $self;
-   Scalar::Util::weaken $q->[-1];
+   weaken $q->[-1];
 
    $self
 }
@@ -251,7 +252,7 @@ sub AnyEvent::Impl::Perl::Io::DESTROY {
    my $fds = $fds[$self->[1]];
 
    # remove watcher from fds structure
-   my $fd = fileno $self->[0];
+   my $fd = $self->[0];
 
    if (@{ $fds->[W][$fd] } == 1) {
       delete $fds->[W][$fd];
@@ -261,7 +262,7 @@ sub AnyEvent::Impl::Perl::Io::DESTROY {
       my $last = pop @$q;
 
       if ($last != $self) {
-         Scalar::Util::weaken ($q->[$self->[3]] = $last);
+         weaken ($q->[$self->[3]] = $last);
          $last->[3] = $self->[3];
       }
    }
@@ -279,7 +280,7 @@ sub timer {
       $self = [$MNOW + $arg{after} , sub {
          $_[0][0] = $MNOW + $ival;
          push @timer, $_[0];
-         Scalar::Util::weaken $timer[-1];
+         weaken $timer[-1];
          $need_sort = $_[0][0] if $_[0][0] < $need_sort;
          &$cb;
       }];
@@ -288,7 +289,7 @@ sub timer {
    }
 
    push @timer, $self;
-   Scalar::Util::weaken $timer[-1];
+   weaken $timer[-1];
    $need_sort = $self->[0] if $self->[0] < $need_sort;
 
    $self
